==> haskell-commonmark-pandoc-0.2.2.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-pandoc
version:              0.2.2.1
visibility:           public
id:                   commonmark-pandoc-0.2.2.1-2zdepom7gRIDNqwO6da0DX
key:                  commonmark-pandoc-0.2.2.1-2zdepom7gRIDNqwO6da0DX
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  87a16221b8879aa79706a485ce45fa78
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-pandoc
hs-libraries:         HScommonmark-pandoc-0.2.2.1-2zdepom7gRIDNqwO6da0DX
depends:
    base-4.17.2.1 commonmark-0.2.5.1-GCJG0FVNXXp5mMKAIammJU
    commonmark-extensions-0.2.5.3-9z2QJupAVEOANDhM4Leyrc
    pandoc-types-1.23.1-35o8OUzLi8nDdUvn3RTMlv text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-pandoc-0.2.2.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-pandoc
version:              0.2.2.1
visibility:           public
id:                   commonmark-pandoc-0.2.2.1-88BcXFO9DSDGfcToMZ6tPR
key:                  commonmark-pandoc-0.2.2.1-88BcXFO9DSDGfcToMZ6tPR
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  6e06cf3ab85355ecbdfbe96d9d3ddc65
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/commonmark-pandoc-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-pandoc
hs-libraries:         HScommonmark-pandoc-0.2.2.1-88BcXFO9DSDGfcToMZ6tPR
depends:
    base-4.17.2.1 commonmark-0.2.5.1-1hzamojCWIUDIdC13AjpuF
    commonmark-extensions-0.2.5.3-DtK5JLJzoEp3WKEyxzuPpp
    pandoc-types-1.23.1-96g5xB5EQNeBDhn3qnDT5u text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
